import request from '@/utils/request'

// 统计当前在线服务器的流量相关的业务数
export function countBusiness() {
  return request({
    url: '/system/screen/countBusinessByTraffic',
    method: 'get'
  })
}
// 当前在线服务器发送带宽总流量
export function sumTrafficByServer() {
  return request({
    url: '/system/screen/sumTrafficByServer',
    method: 'get'
  })
}
// 当前在线交换机接收带宽总流量
export function sumTrafficBySwitch() {
  return request({
    url: '/system/screen/sumTrafficBySwitch',
    method: 'get'
  })
}
// 交换机在线数量
export function countSwitchNum() {
  return request({
    url: '/system/screen/countSwitchNum',
    method: 'get'
  })
}
// 服务器在线率
export function serverOnlineRate() {
  return request({
    url: '/system/screen/getServerOnlineRate',
    method: 'get'
  })
}
// 当日业务的在线设备数量统计TOP5
export function countDeviceNumTop5() {
  return request({
    url: '/system/screen/countDeviceNumTop5',
    method: 'get'
  })
}
